@@ -70,10 +70,11 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_ensure('absent')}
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('log_filters').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('<SERVICE DEFAULT>').with_quote(true)}
+      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -111,6 +112,8 @@ describe 'nova::compute::libvirt' do
           :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
           :ovs_timeout                                => 10,
           :max_queues                                 => 4,
+          :num_memory_encrypted_guests                => 255,
+          :modular_libvirt                            => true,
         }
       end
 
@@ -144,10 +147,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('"1:file:/var/log/libvirt/libvirtd.log"')}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value('"1:qemu"')}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('"NORMAL:-VERS-SSL3.0"')}
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value(10)}
+      it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
